/*
 * Parametros.java
 *
 * Created on 5 de marzo de 2006, 1:59
 */

package Flier_Match.FMCliente.sistema;
import java.awt.event.KeyEvent;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.Properties;
/**
 *
 * @author  Luis Rocha
 * @version 
 */
public class Parametros implements Serializable{
	public int adelante;
	public int atras;
	public int giroIzq;
	public int giroDer;
	public int giroArr;
	public int giroAba;
	public int strafe;
	public int estabilizar;
	public int disparoBala;
	public int disparoMisil;
	public int chat;
    
	public String host;
	public String puerto;
    
    private int render;//1=software, 2=opengl
    public final static int SOFTWARRE=1;
    public final static int OPENGL=2;
    public final static int GLCANVAS=3;
    
    private int resolucion [];
    
    public String nickname;
    private int color;//1=rojo, 2=azul, 3=verde, 4=blanco, 5=amarillo
    
    public final static long sleepThread=50;//es el tiempo de espera entre cada iteracion del manejador de eventos
    
    private Properties mapaChars;
    
    /** Creates new Parametros */
    public Parametros() {
        asignarDefecto ();
    }
    
    /**
     *asigna a esta clase los valores por defecto del juego.
     */
    public void asignarDefecto () {
        KeyEvent event=null;
        render=1;
        resolucion=new int [2];
        resolucion [0]=640;
        resolucion [1]=480;
        
        host="localhost";
        puerto="8888";
        
        nickname="Jugador";
        color=1;
        
        adelante=event.VK_A;
        atras=event.VK_Z;
        giroIzq=event.VK_LEFT;
        giroDer=event.VK_RIGHT;
        giroArr=event.VK_DOWN;
        giroAba=event.VK_UP;
        strafe=event.VK_SHIFT;
        estabilizar=event.VK_Q;
        disparoBala=event.VK_CONTROL;
        disparoMisil=event.VK_SPACE;
        chat=event.VK_T;
    }
    
    /**
     *Guarda el estado de esta clase en un archivo llamado parametros.cnf 
     *dentro de la carpeta FMCliente, si el archivo no existe guarda la
     *configuracion por defecto.
     */
    public boolean guardar () {
        File confirm=new File (getPath ()+"parametros.cnf");
        if (!confirm.exists ()) asignarDefecto ();
        
        try {
            FileOutputStream salidaArchivos=new FileOutputStream (getPath ()+"parametros.cnf");
            ObjectOutputStream salidaObjetos=new ObjectOutputStream (salidaArchivos);
            salidaObjetos.writeObject (this);
            salidaObjetos.close ();
            salidaArchivos.close ();
            return true;
        } catch (Exception E) {
            System.out.println ("Error guardando la configuracion");
            E.printStackTrace ();
            return false;
        }
    }
    
    /**
     *Carga en esta clase los parametros contenidos en un archivo llamado
     *parametros.cnf dentro de la carpeta FMCliente si el archivo no existe
     *entonces carga las configuraciones por defecto y las guarda.
     */
    public Parametros cargar () {
        try {
            File confirm=new File (getPath ()+"parametros.cnf");
            if (confirm.exists ()) {
                FileInputStream entradaArchivos=new FileInputStream (getPath ()+"parametros.cnf");
                ObjectInputStream entradaObjetos=new ObjectInputStream (entradaArchivos);
                Parametros P=(Parametros) entradaObjetos.readObject ();
                entradaObjetos.close ();
                entradaArchivos.close ();
                return P;
            } else {
                asignarDefecto ();
                if (guardar ()) return this;
                else {
                    System.out.println ("Ha existido un error guardando la configuracion por defecto al cargar");
                    return null;
                }
            }
        } catch (Exception E) {
            System.out.println ("Error cargando la configuracion");
            E.printStackTrace ();
            return null;
        }
    }
    
    /**
     *Obtiene la direccion absulta del package en donde esta instalado
     *el sistema del cliente.
     */
    public String getPath () {
        return (""+this.getClass().getResource("../../../").getFile().replace("%20", " "));
    }
    
    /**
     * Devuelve el identificador del color, 1 si es rojo, 2 si es azul
     * 3 si es verde, 4 si es blanco o 5 si es amarillo.
     */
    public int getColor () {
        return color;
    }
    
    /**
     * Asigna un valor al atributo color.
     */
    public void setColor (int idc) {
        color=idc;
    }
    
    /**
     * Devuelve el nombre del NickName.
     */
    public String getNickname () {
        return nickname;
    }
    
    /**
     * Asigna un valor al atributo Nickname.
     */
    public void setNickname (String idn) {
        nickname=idn;
    }
    
    /**
     * Devuelve el identificador del render, 1 si es software o 2 si es Open Gl.
     */
    public int getRender () {
        return render;
    }
    
    /**
     * Asigna un valor al atributo render.
     */
    public void setRender (int idr) {
        render=idr;
    }
    
    /**
     * Devuelve la resolucion de pantalla asignada para el render.
     */
    public int[] getResolucion () {
        return resolucion;
    }
    
    /**
     * Asigna un valor al atributo resolucion, los parametros que recibe
     * son el ancho y alto de la resolucion.
     */
    public void setResolucion (int w, int h) {
        resolucion [0]=w;
        resolucion [1]=h;
    }
    
    /**
     * Devuelve un String que identifica la posicion de la letra dentro de un mapa de caracteres ubicado en el archivo CHARMAP.PROP
     * 
     * @param letra es la letra de la cual se quiere obtener el id
     * @return el identificador de la letra en un mapa de caracteres
     */
    public String getLetraId (char letra) {
    	try {
        	String id=(String)mapaChars.getProperty(""+letra);
        	return (id);
    	} catch (Exception E) {
    		E.printStackTrace();
    		return null;
    	}

    }
    
    /**
     * Carga un archivo property con el mapa de los caracteres a usar
     * 
     * @param path Es la ruta del archivo properties con el mapa de las letras respectivas
     */
    public void cargarMapaChars (String path) {
    	try {
    		FileInputStream input=new FileInputStream (path);
        	mapaChars=new Properties ();
        	mapaChars.load(input);
    	} catch (Exception E) {
    		E.printStackTrace();
    	}
    }

}
